package net.unoh.snow;

import java.awt.Canvas;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Image;
import java.awt.RenderingHints;
import java.io.File;
import java.io.IOException;
import java.util.List;

import javax.imageio.ImageIO;

public class SnowCanvas extends Canvas {

	private static final Color SNOW_COLOR = Color.WHITE;

	private static final Color BACKGROUND_COLOR = Color.BLACK;

	private static final long serialVersionUID = 1L;

	private List<Snow> snows = null;

	private Image backgroundImage = null;

	public SnowCanvas() {
		super();
	}

	public SnowCanvas(String backgroundImagePath) {
		super();
		try {
			backgroundImage = ImageIO.read(new File(backgroundImagePath));
		} catch (IOException e) {
			System.out.println("background image is not found.");
		}
	}

	public void update(Graphics g) {

		clear(g);

		if (snows != null) {

			g.setColor(SNOW_COLOR);
			((Graphics2D) g).setRenderingHint(
					RenderingHints.KEY_ANTIALIASING,
					RenderingHints.VALUE_ANTIALIAS_ON);

			synchronized (snows) {
				for (Snow snow : snows) {
					if (snow.isDraw()) {
						g.fillOval(snow.getX(), snow.getY(),
								Snow.WIDTH, Snow.HEIGHT);
					}
				}
			}
		}
	}

	public void setSnows(List<Snow> snows) {
		this.snows = snows;
	}

	protected void clear(Graphics g) {
		if (backgroundImage == null) {
			g.setColor(BACKGROUND_COLOR);
			g.fillRect(0, 0, SnowFrame.MAX_WIDTH, SnowFrame.MAX_HEIGHT);
		} else {
			g.drawImage(backgroundImage, 0, 0,
					SnowFrame.MAX_WIDTH, SnowFrame.MAX_HEIGHT, this);
		}
	}

}
